import { Include, Meta, UnitConfig, UnitResponse } from "../types/common";
import { CheckPayment, CheckPaymentStatus, ApproveCheckPaymentRequest, ReturnCheckPaymentRequest, BaseCheckPaymentListParams, CreateCheckPaymentRequest } from "../types/checkPayment";
import { BaseResource } from "./baseResource";
import { Account, Customer, Transaction } from "../types";
import { responseEncoding, ResponseType } from "axios";
type CheckPaymentIncluded = Include<Account[] | Customer[] | Transaction[]>;
export declare class CheckPayments extends BaseResource {
    constructor(token: string, basePath: string, config?: UnitConfig);
    create(request: CreateCheckPaymentRequest): Promise<UnitResponse<CheckPayment>>;
    get(id: string, include?: string): Promise<UnitResponse<CheckPayment> & CheckPaymentIncluded>;
    return(request: ReturnCheckPaymentRequest): Promise<UnitResponse<CheckPayment>>;
    approve(request: ApproveCheckPaymentRequest): Promise<UnitResponse<CheckPayment>>;
    getImage(id: string, front?: boolean, responseEncoding?: responseEncoding, responseType?: ResponseType): Promise<string>;
    list(params?: CheckPaymentListParams): Promise<UnitResponse<CheckPayment[]> & CheckPaymentIncluded & Meta>;
    cancel(id: string): Promise<UnitResponse<CheckPayment>>;
}
export interface CheckPaymentListParams extends BaseCheckPaymentListParams {
    /**
     * Optional. Filter by status (Processed, PendingReview, MarkedForReturn or Returned). Usage example: filter[status][0]=Processed
     */
    status?: CheckPaymentStatus[];
    /**
     * Optional. A comma-separated list of related resources to include in the response. Related resources include: customer, account, transaction.
     * See [Getting Related Resources](https://docs.unit.co/about-jsonapi/#intro-getting-related-resources)
     */
    include?: string;
}
export {};
