import { Account } from "../types/account";
import { BaseListParams, Include, Meta, Sort, Tags, UnitConfig, UnitResponse } from "../types/common";
import { Customer } from "../types/customer";
import { AchReceivedPayment, PatchAchReceivedPaymentRequest, ReceivedPaymentStatus } from "../types/payments";
import { Transaction } from "../types/transactions";
import { BaseResource } from "./baseResource";
export declare class ReceivedPayments extends BaseResource {
    constructor(token: string, basePath: string, config?: UnitConfig);
    update(id: string, request: PatchAchReceivedPaymentRequest): Promise<UnitResponse<AchReceivedPayment>>;
    advance(id: string): Promise<UnitResponse<AchReceivedPayment>>;
    /**
     * @param include
     * Optional. A comma-separated list of related resources to include in the response.
     * Related resources include: customer, account. See Getting Related Resources
     */
    get(id: string, include?: string): Promise<UnitResponse<AchReceivedPayment> & Include<Account[] | Customer[]>>;
    list(params?: ReceivedPaymentListParams): Promise<UnitResponse<AchReceivedPayment[]> & Include<Account[] | Customer[] | Transaction[]> & Meta>;
}
export interface ReceivedPaymentListParams extends BaseListParams {
    /**
     * Optional. Filters the results by the specified account id.
     * default: empty
     */
    accountId?: string;
    /**
     * Optional. Filters the results by the specified customer id.
     * default: empty
     */
    customerId?: string;
    /**
     * Optional. Filter Applications by Tags.
     * default: empty
     */
    tags?: Tags;
    /**
     * Optional. Filter Received Payments by ReceivedPayment Status. Usage example: filter[status][0]=Pending&filter[status][1]=Advanced. cant be stated with includeCompleted.
     */
    status?: ReceivedPaymentStatus[];
    /**
     * Optional. Filter to include ReceivedPayment with Status 'Completed', default False. cant be stated with filter[status[]
     */
    includeCompleted?: boolean;
    /**
     * Optional. Leave empty or provide sort = createdAt for ascending order.Provide sort = -createdAt(leading minus sign) for descending order.
     * default: sort=-createdAt
     */
    sort?: Sort;
    /**
    * Optional. A comma-separated list of related resources to include in the response.
    * Related resources include: customer, account. [See Getting Related Resources](https://developers.unit.co/#intro-getting-related-resources)
    */
    include?: string;
}
