"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ReceivedPayments = void 0;
const baseResource_1 = require("./baseResource");
class ReceivedPayments extends baseResource_1.BaseResource {
    constructor(token, basePath, config) {
        super(token, basePath + "/received-payments", config);
    }
    async update(id, request) {
        return this.httpPatch(`/${id}`, { data: request });
    }
    async advance(id) {
        return this.httpPost(`/${id}/advance`);
    }
    /**
     * @param include
     * Optional. A comma-separated list of related resources to include in the response.
     * Related resources include: customer, account. See Getting Related Resources
     */
    async get(id, include) {
        const params = { ...(include && { include }) };
        return this.httpGet(`/${id}`, { params });
    }
    async list(params) {
        const parameters = {
            "page[limit]": ((params === null || params === void 0 ? void 0 : params.limit) ? params.limit : 100),
            "page[offset]": ((params === null || params === void 0 ? void 0 : params.offset) ? params.offset : 0),
            ...((params === null || params === void 0 ? void 0 : params.accountId) && { "filter[accountId]": params.accountId }),
            ...((params === null || params === void 0 ? void 0 : params.customerId) && { "filter[customerId]": params.customerId }),
            ...((params === null || params === void 0 ? void 0 : params.tags) && { "filter[tags]": this.customStringify(params.tags, ":") }),
            ...((params === null || params === void 0 ? void 0 : params.includeCompleted) && { "filter[includeCompleted]": params.includeCompleted }),
            "sort": (params === null || params === void 0 ? void 0 : params.sort) ? params.sort : "-createdAt",
            "include": (params === null || params === void 0 ? void 0 : params.include) ? params.include : ""
        };
        if (params === null || params === void 0 ? void 0 : params.status)
            params.status.forEach((s, idx) => {
                parameters[`filter[status][${idx}]`] = s;
            });
        return this.httpGet("", { params: parameters });
    }
}
exports.ReceivedPayments = ReceivedPayments;
