"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RecurringPayments = void 0;
const baseResource_1 = require("./baseResource");
class RecurringPayments extends baseResource_1.BaseResource {
    constructor(token, basePath, config) {
        super(token, basePath + "/recurring-payments", config);
    }
    async create(request) {
        return this.httpPost("", { data: request });
    }
    async disable(paymentId) {
        // NB: We must pass an empty body here because the API is returning a 415 for any requests made
        //  to this endpoint from this SDK: Content-Type must be application/vnd.api+json
        //  However, there is code in Axios that strips the Content-Type from the request whenever 
        //  there is no body since it makes no sense to provide it + makes the data over the wire
        //  that much smaller:  
        //   https://github.com/axios/axios/blob/649d739288c8e2c55829ac60e2345a0f3439c730/dist/axios.js#L1449-L1450
        // TODO: Remove the empty body after we update the API to not throw 415 for missing Content-Type 
        //  when the body is empty.
        return this.httpPost(`/${paymentId}/disable`, { data: {} });
    }
    async enable(paymentId) {
        // NB: We must pass an empty body here because the API is returning a 415 for any requests made
        //  to this endpoint from this SDK: Content-Type must be application/vnd.api+json
        //  However, there is code in Axios that strips the Content-Type from the request whenever 
        //  there is no body since it makes no sense to provide it + makes the data over the wire
        //  that much smaller:  
        //   https://github.com/axios/axios/blob/649d739288c8e2c55829ac60e2345a0f3439c730/dist/axios.js#L1449-L1450
        // TODO: Remove the empty body after we update the API to not throw 415 for missing Content-Type 
        //  when the body is empty.
        return this.httpPost(`/${paymentId}/enable`, { data: {} });
    }
    async delete(paymentId) {
        // NB: We must pass an empty body here because the API is returning a 415 for any requests made
        //  to this endpoint from this SDK: Content-Type must be application/vnd.api+json
        //  However, there is code in Axios that strips the Content-Type from the request whenever
        //  there is no body since it makes no sense to provide it + makes the data over the wire
        //  that much smaller:
        //   https://github.com/axios/axios/blob/649d739288c8e2c55829ac60e2345a0f3439c730/dist/axios.js#L1449-L1450
        // TODO: Remove the empty body after we update the API to not throw 415 for missing Content-Type
        //  when the body is empty.
        return this.httpDelete(`/${paymentId}`, { data: {} });
    }
    async get(paymentId) {
        return this.httpGet(`/${paymentId}`);
    }
    async list(params) {
        const parameters = {
            "page[limit]": ((params === null || params === void 0 ? void 0 : params.limit) ? params.limit : 100),
            "page[offset]": ((params === null || params === void 0 ? void 0 : params.offset) ? params.offset : 0),
            ...((params === null || params === void 0 ? void 0 : params.accountId) && { "filter[accountId]": params.accountId }),
            ...((params === null || params === void 0 ? void 0 : params.customerId) && { "filter[customerId]": params.customerId }),
            ...((params === null || params === void 0 ? void 0 : params.tags) && { "filter[tags]": this.customStringify(params.tags, ":") }),
            ...((params === null || params === void 0 ? void 0 : params.fromStartTime) && { "filter[fromStartTime]": params.fromStartTime }),
            ...((params === null || params === void 0 ? void 0 : params.toStartTime) && { "filter[toStartTime]": params.toStartTime }),
            ...((params === null || params === void 0 ? void 0 : params.fromEndTime) && { "filter[fromEndTime]": params.fromEndTime }),
            ...((params === null || params === void 0 ? void 0 : params.toEndTime) && { "filter[toEndTime]": params.toEndTime }),
            "sort": (params === null || params === void 0 ? void 0 : params.sort) ? params.sort : "-createdAt"
        };
        if (params === null || params === void 0 ? void 0 : params.status)
            params.status.forEach((s, idx) => {
                parameters[`filter[status][${idx}]`] = s;
            });
        if (params === null || params === void 0 ? void 0 : params.type)
            params.type.forEach((t, idx) => {
                parameters[`filter[type][${idx}]`] = t;
            });
        return this.httpGet("", { params: parameters });
    }
}
exports.RecurringPayments = RecurringPayments;
