import { BaseListParams, Sort, UnitConfig, UnitResponse } from "../types";
import { CreateRecurringRepaymentRequest, RecurringRepayment, RecurringRepaymentStatus } from "../types/recurringRepayments";
import { BaseResource } from "./baseResource";
export declare class RecurringRepayments extends BaseResource {
    constructor(token: string, basePath: string, config?: UnitConfig);
    create(request: CreateRecurringRepaymentRequest): Promise<UnitResponse<RecurringRepayment>>;
    get(repaymentId: string): Promise<UnitResponse<RecurringRepayment>>;
    disable(repaymentId: string): Promise<UnitResponse<RecurringRepayment>>;
    enable(repaymentId: string): Promise<UnitResponse<RecurringRepayment>>;
    list(params?: RecurringPaymentListParams): Promise<UnitResponse<RecurringRepayment[]>>;
}
export interface RecurringPaymentListParams extends BaseListParams {
    /**
     * Optional. Filters the results by the specified credit account id.
     * default: empty
     */
    creditAccountId?: string;
    /**
     * Optional. Filters the results by the specified customer id.
     * default: empty
     */
    customerId?: string;
    /**
     * Optional. Filter recurring payments by status (Active or Disabled). Usage example: *filter[status][0]=Active
     */
    status?: RecurringRepaymentStatus[];
    /**
     * RFC3339 format. For more information: https://en.wikipedia.org/wiki/ISO_8601#RFCs
     * Optional. Filters the Recurring Payments that their start time occurred after the specified date. e.g. 2022-06-13
     */
    fromStartTime?: string;
    /**
     * RFC3339 format. For more information: https://en.wikipedia.org/wiki/ISO_8601#RFCs
     * Optional. Filters the Recurring Payments that their start time occurred before the specified date. e.g. 2022-05-13
     */
    toStartTime?: string;
    /**
     * Optional. Leave empty or provide sort = createdAt for ascending order.Provide sort = -createdAt(leading minus sign) for descending order.
     * default: sort=-createdAt
     */
    sort?: Sort;
}
