import { BaseListParams, Meta, UnitConfig, UnitResponse } from "../types/common";
import { CreateRepaymentRequest, Repayment } from "../types/repayments";
import { BaseResource } from "./baseResource";
export declare class Repayments extends BaseResource {
    constructor(token: string, basePath: string, config?: UnitConfig);
    create(request: CreateRepaymentRequest): Promise<UnitResponse<Repayment>>;
    get(id: string): Promise<UnitResponse<Repayment>>;
    list(params?: RepaymentListParams): Promise<UnitResponse<Repayment[]> & Meta>;
}
export interface RepaymentListParams extends BaseListParams {
    /**
     * Optional. Filters the results by the specified account id.
     * default: empty
     */
    accountId?: string;
    /**
     * Optional. Filters the results by the specified account id.
     * default: empty
     */
    creditAccountId?: string;
    /**
     * Optional. Filters the results by the specified customer id.
     * default: empty
     */
    customerId?: string;
    /**
     * Optional. Filter repayments by status (Pending, PendingReview, Returned, Sent or Rejected). Usage example: *filter[status][0]=Active
     */
    status?: string[];
    /**
     * Optional. Filter repayments by Repayment type. such as (AchRepayment, BookRepayment). Usage example: filter[type][0]=AchRepayment&filter[type][1]=BookRepayment
     */
    type?: string[];
    /**
     * Optional. Filters the result according to the associated [Recurring Repayment](https://www.unit.co/docs/api/recurring-repayments/) id
     */
    recurringRepayment?: string;
}
