"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Webhooks = void 0;
const baseResource_1 = require("./baseResource");
const crypto = require("crypto");
class Webhooks extends baseResource_1.BaseResource {
    constructor(token, basePath, config) {
        super(token, basePath + "/webhooks", config);
    }
    async create(request) {
        return this.httpPost("", { data: request });
    }
    async get(id) {
        return this.httpGet(`/${id}`);
    }
    async list(params) {
        const parameters = {
            "page[limit]": ((params === null || params === void 0 ? void 0 : params.limit) ? params.limit : 100),
            "page[offset]": ((params === null || params === void 0 ? void 0 : params.offset) ? params.offset : 0),
            ...((params === null || params === void 0 ? void 0 : params.since) && { "filter[since]": params.since }),
            ...((params === null || params === void 0 ? void 0 : params.until) && { "filter[until]": params.until }),
            ...((params === null || params === void 0 ? void 0 : params.fromId) && { "filter[fromId]": params.fromId }),
            ...((params === null || params === void 0 ? void 0 : params.toId) && { "filter[toId]": params.toId }),
        };
        return this.httpGet("", { params: parameters });
    }
    async update(id, request) {
        return this.httpPatch(`/${id}`, { data: request });
    }
    async enable(id) {
        return this.httpPost(`/${id}/enable`);
    }
    async disable(id) {
        return this.httpPost(`/${id}/disable`);
    }
    verify(signature, secret, payload) {
        const hmac = crypto.createHmac("sha1", secret);
        hmac.update(JSON.stringify(payload));
        return hmac.digest("base64") == signature;
    }
}
exports.Webhooks = Webhooks;
